# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.list_users_response import ListUsersResponse

class TestListUsersResponse(unittest.TestCase):
    """ListUsersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListUsersResponse:
        """Test ListUsersResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListUsersResponse`
        """
        model = ListUsersResponse()
        if include_optional:
            return ListUsersResponse(
                users = [
                    perceptic_core_client.models.user_info_response.UserInfoResponse(
                        user_id = '', 
                        username = '', 
                        email = '', 
                        first_name = '', 
                        last_name = '', )
                    ],
                total_count = 56,
                next_offset = 56
            )
        else:
            return ListUsersResponse(
        )
        """

    def testListUsersResponse(self):
        """Test ListUsersResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
